@@ -1,6 +1,9 @@
 import datetime
 import inspect
 import logging
+import os
+from typing import Callable
+
 import requests
 import uvicorn
 from fastapi import FastAPI
@@ -10,16 +13,16 @@ from fastapi.middleware.cors import CORSMiddleware
 from fastapi.middleware.gzip import GZipMiddleware
 from fastapi.responses import RedirectResponse
 from starlette.middleware.sessions import SessionMiddleware
-from typing import Callable
 
 from opentelemetry_wrapper import instrument_all
+from opentelemetry_wrapper import instrument_fastapi_app
 
-instrument_all()
+instrument_all(clobber_other_log_handlers=True)
 
-app = FastAPI(title='My Super Project',
-              description='This is a very fancy project, with auto docs for the API and everything',
-              version='2.5.0',  # only semver makes sense here
-              )
+app = instrument_fastapi_app(FastAPI(title='My Super Project',
+                                     description='This is a very fancy project, with docs for the API and everything',
+                                     version='2.5.0',  # only semver makes sense here
+                                     ))
 
 app.add_middleware(GZipMiddleware, minimum_size=1000)
 app.add_middleware(SessionMiddleware, secret_key='config.settings.secret_key')
@@ -51,7 +54,7 @@ def hello() -> str:
 
 
 @app.get('/hello/{name}')
-def hello(name: str) -> str:
+def hello2(name: str) -> str:
     logging.info(f'called `hello/{name}`')
     return 'hello'
 
@@ -65,12 +68,18 @@ def hello_hello() -> str:
 
 
 if __name__ == '__main__':
+    # this only works because the env vars are preserved in the spawned processes
+    # otherwise, setting these after initializing otel wrapper would obviously fail
+    os.environ['OTEL_EXPORTER_PROMETHEUS_PORT'] = '9464'
+    os.environ['OTEL_EXPORTER_PROMETHEUS_ENDPOINT'] = '/metrics'
+
     uvicorn.run(f'{inspect.getmodulename(__file__)}:app',
                 host='localhost',
                 port=8000,
-                reload=True,
+                # reload=True,
                 access_log=True,
-                # workers=2,  # not valid with reload=True
+                workers=2,  # not valid with reload=True
                 # proxy_headers=True,  # github.com/encode/uvicorn/blob/master/uvicorn/middleware/proxy_headers.py
                 limit_concurrency=128,
+                # log_config=None, # this tells uvicorn not to set up its own logger
                 )
